link

Macro link 

link!() { /* proc-macro */ }
Specifies relationships between the current document and an external resource. This element is most commonly used to link to CSS but is also used to establish site icons (both “favicon” style icons and icons for the home screen and apps on mobile devices) among other things.