small

Macro small 

small!() { /* proc-macro */ }
Represents side-comments and small print, like copyright and legal text, independent of its styled presentation. By default, it renders text within it one font size smaller, such as from small to x-small.