sub

Macro sub 

sub!() { /* proc-macro */ }
Specifies inline text which should be displayed as subscript for solely typographical reasons. Subscripts are typically rendered with a lowered baseline using smaller text.